package com.xcheng.scanner;

import android.app.Fragment;
import android.preference.PreferenceFragment;
import android.os.Bundle;
import android.os.Handler;
import android.os.HandlerThread;
import android.os.Looper;
import android.os.Message;
import android.os.Vibrator;
import android.os.AsyncTask;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.preference.ListPreference;
import android.preference.Preference;
import android.preference.PreferenceScreen;
import android.preference.PreferenceActivity;
import android.preference.SwitchPreference;
import android.util.Log;
import android.text.TextUtils;
import android.widget.Toast;
import java.util.ArrayList;
import java.util.List;
import android.preference.PreferenceManager;
import android.content.SharedPreferences;


public class ModuleSettingFragment extends PreferenceFragment implements
        Preference.OnPreferenceChangeListener {
    private static final String TAG = "ModuleSettingFragment";

    private static final String KEY_ALL_SWITCH = "swtich_all";
    private static final String KEY_ALL_SETTING = "all_setting";

    public static final int MSG_ENABLE_ALL_TYPE = 0x01;
    public static final int MSG_DISABLE_ALL_TYPE = 0x02;

    private SwitchPreference mAllSwitchPref;

    private ScanThreadHandler mScanTheadHandler;
    private HandlerThread mHandlerThread;

    private boolean mEnabled = false;


    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        addPreferencesFromResource(R.xml.barcode_module_setting);

        mAllSwitchPref = (SwitchPreference) findPreference(KEY_ALL_SWITCH);
        mAllSwitchPref.setOnPreferenceChangeListener(this);

        mHandlerThread = new HandlerThread("ScanSettingThread");
        mHandlerThread.start();
        mScanTheadHandler = new ScanThreadHandler(mHandlerThread.getLooper());
    }

    @Override
    public boolean onPreferenceChange(Preference preference, Object objValue) {
        mEnabled = (Boolean) objValue;
        Log.d(TAG, "onPreferenceChange: mEnabled = " + mEnabled);
        final Message msg = Message.obtain();
        msg.obj = 0;
        if (mEnabled) {
            msg.what = MSG_ENABLE_ALL_TYPE;
        } else {
            msg.what = MSG_DISABLE_ALL_TYPE;
        }
        mScanTheadHandler.sendMessage(msg);
        return true;
    }

    @Override
    public void onResume() {
        super.onResume();
        SharedPreferences prefs = PreferenceManager.getDefaultSharedPreferences(getContext());
        mEnabled = prefs.getBoolean(KEY_ALL_SWITCH, false);
        if (mAllSwitchPref != null) {
            mAllSwitchPref.setChecked(mEnabled);
        }
    }

    @Override
    public void onPause() {
        super.onPause();
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        if (mScanTheadHandler != null) {
            mScanTheadHandler.removeCallbacksAndMessages(null);
        }
        mHandlerThread.quit();
    }

    class ScanThreadHandler extends Handler {
        public ScanThreadHandler(Looper looper) {
            super(looper);
        }

        @Override
        public void handleMessage(Message msg) {
            Bundle bundle;
            switch (msg.what) {
                case MSG_ENABLE_ALL_TYPE:
                    int entype = (int)msg.obj;
                    if (!ScanNative.enableType(entype)) {
                        final Message enMsg = Message.obtain();
                        enMsg.what = MSG_ENABLE_ALL_TYPE;
                        enMsg.obj = entype;
                        mScanTheadHandler.sendMessage(enMsg);
                    }
                    break;
                case MSG_DISABLE_ALL_TYPE:
                    int distype = (int)msg.obj;
                    if (!ScanNative.disableType(distype)) {
                        final Message disMsg = Message.obtain();
                        disMsg.what = MSG_DISABLE_ALL_TYPE;
                        disMsg.obj = distype;
                        mScanTheadHandler.sendMessage(disMsg);
                    }
                    break;
            }
        }
    }
}


